// mozileUtilities.js

/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/*******

Mozile Utilities Javascript
Mozile version 0.6.16

Created by James A. Overton
Created on 2004-03-24

Last revised by James A. Overton
Last revised on 2004-11-16

HISTORY:
	Some code in this file was first found in mozilehtmltb.js, while the 
majority was cut out of mozileTB.js and separated into different files.


DESCRIPTION:
	General functions which belong nowhere else.

*********/

/*
Mozile Debug Levels
0 = Really important, alert the user right away, add to debug array
1 = Important, always show this in the status, add to debug array
2 = Not important, add to debug array
3 = Unimportant, add to debug array

*/
	
	// Listen for onbeforeunload events, and pass them to the mozileOnBeforeUnload handler
document.addEventListener("beforeunload", mozileOnBeforeUnload, false);
var mozileLastUnloaded = "";

function mozileOnBeforeUnload(event) {
	var f=["mozileUtilities.js","mozileOnBeforeUnload"];
	mozileDebug(f,2,"Page Unloading.");
	
	netscape.security.PrivilegeManager.enablePrivilege('UniversalXPConnect');
    var mozilePrefs = Components.classes["@mozilla.org/preferences-service;1"].
        getService(Components.interfaces.nsIPrefBranch);
    
	try {
		
			// if the promptOnUnloadBool preference is "false", do nothing
		if(!mozilePrefs.getBoolPref("mozile.promptOnUnloadBool")) return false;

			// Make mTarg the document that is being closed
		var mTarg;
		if(event.target.nodeType!=9) {
			mTarg = event.target.ownerDocument;
		}
		else {
			mTarg = event.target;
		}
				
		mozileDebug(f,1,"Unload event:"+ event + event.target +" "+ event.target.nodeType +" "+ mTarg.URL);
		
		if(mTarg.MOZILE_CURRENT_CONFIG['saved'] == "false") {
				// note this page
			mozileDebug(f,1,"Unloading Document");
			event.stopPropagation();
			event.returnValue = false;
			event.preventDefault();
			return false;
		}
  	
  }
  catch (e) {
  	mozileDebug(f,2,"Nothing to unload? "+e);
  }
  return true;
}

var mozileDebugArray = new Array();

function mozileDebug(f,level,msg) {
	mozileDebugLevel = mozilePrefs.getIntPref("mozile.debugLevelInt");
	
		// act only if the level of the message is higher than the mozileDebugLevel
	//if(level >= mozileDebugLevel) {
	
	var message = "Mozile: ["+ f +"] "+ msg; 
		
		// Critical behaviours
	if(level == 0) {
		alert(message);
	}
	if(level == 1) {
		window.status = message;
	}
	
		// Ignore these debug events
	if(level > 1 && mozileDebugLevel < 1) {
		return;
	}
	if(level > 2 && mozileDebugLevel < 2) {
		return;
	}

		// Log to the debugging array	
	
	var datestamp = 
		mozileDD('FullYear')	+"-"+
		mozileDD('Month')			+"-"+
		mozileDD('Date')			+" "+
		mozileDD('Hours')			+":"+
		mozileDD('Minutes')		+":"+
		mozileDD('Seconds');
	
	var entry = new Array(datestamp,f,level,msg);
	mozileDebugArray.push(entry);

}

	// Returns date strings as two digits (with leading "0") if they are 1 digit long
var mozileDates = new Object();


function mozileDD(command) {
		// first see if we've already recorded it...
	if(command in mozileDates) {
		return mozileDates[command];
	}
	
	var d = new Date();
	var commandString = "d.get"+command+"()";
	var str = eval(commandString)+"";
	if(str.length==1) {
		str = "0"+str;
	}
	if(command=="FullYear" || command=="Month" || command=="Date") {
		mozileDates[command]=str;
	}

	return str;
}

function mozileDebugAlert() {
	alert(mozileDebugArray);
}



function mozileGetContext(sel) {
	var f = ["mozileUtilities.js","mozileGetContext"];
	mozileDebug(f,3,"Selection: "+sel);
	if(sel.anchorNode.nodeType==1) {
		return sel.anchorNode;
	}
	if(sel.anchorNode.parentNode.nodeType==1) {
		return sel.anchorNode.parentNode;
	}
	mozileDebug(f,2,"No anchor node?: "+sel.anchorNode);
	return false;
}



function mozileRemoveChildren(node) {	
	if(node.hasChildNodes()!=true) {
		return node;
	}
	var children = node.childNodes;	
	for(var i=0; i<children.length; i++) {
		node.removeChild(children[i]);
	}
	return node;
}



function mozileAlert(name) {
	alert("Mozile Alert: "+name);
}	


function printXML(XML) {
	var objXMLSerializer = new XMLSerializer;
	output = objXMLSerializer.serializeToString(XML);
		// fix stupid uppercase tags!
	output = output.replace( /<(\/?)([A-Z]+)/g,
		function (output,p1,p2,offset,s) {
			return '<'+p1+p2.toLowerCase() ;
		} ) ;
	return output;
}

function dumpText(text) {
	var ta = document.getElementById("here");
	ta = mozileRemoveChildren(ta);
	var tn = document.createTextNode(text);
	ta.appendChild(tn);
}

function dumpXML(XML) {
	dumpText(printXML(XML));
}





// Call a few functions that should only be called once everything else has been done.
// Killed in favour of the new Firefox update mechanism
// mozileAutoUpdate();